#!/usr/bin/env python

import json
import requests

from packaging.version import parse

PYPI_URL = 'https://pypi.python.org/pypi/{package}/json'
PACKAGE_NAME = 'go1-cli'


class Version:
    @staticmethod
    def get_version() -> str:
        """Return version of package on pypi.python.org using json.
        :rtype: str
        """
        req = requests.get(PYPI_URL.format(package=PACKAGE_NAME))
        version = parse('0')
        if req.status_code == requests.codes.ok:
            j = json.loads(req.text.encode())
            releases = j.get('releases', [])
            for release in releases:
                ver = parse(release)
                if not ver.is_prerelease:
                    version = max(version, ver)

        return '%s %s' % (PACKAGE_NAME, str(version))
